import {
  Controller,
  Put,
  UseGuards,
  Get,
  Param,
  UsePipes,
  ValidationPipe,
  Body,
} from '@nestjs/common';

import { AuthGuard } from '../shared/auth.guard';
import { DrawService } from './draw.service';
import { Roles } from '../shared/roles.decorator';

/*
      DrawController
  
      Functions either insert or return MapDrawing data,
      Insert functions require user to have proper role (either gm or commander) in the game to be able store the ddata: MapDrawingDTOata to database.
      Data return functions require atleast spectator role.
  */
@Controller('draw')
export class DrawController {
  constructor(private drawService: DrawService) {}

  @Put('mapdrawing/:id')
  @UsePipes(new ValidationPipe())
  @Roles('admin', 'factionleader')
  async draw(@Param('id') gameId, @Body() data) {
    return this.drawService.draw(gameId, data);
  }

  @Get('map/:id')
  @UseGuards(new AuthGuard())
  @UsePipes(new ValidationPipe())
  async drawMap(@Param('id') id, @Body() data) {
    return this.drawService.drawMap(id, data);
  }
}
