import {
  Controller,
  Get,
  Post,
  Param,
  UseGuards,
  UsePipes,
  Body,
} from '@nestjs/common';
import { TrackingService } from './tracking.service';
import { Roles } from '../shared/roles.decorator';
import { AuthGuard } from '../shared/auth.guard';
import { ValidationPipe } from '../shared/validation.pipe';
import { TrackingDTO } from './tracking.dto';
import { User } from 'src/user/user.decorator';

@Controller('tracking')
export class TrackingController {
  constructor(private trackingservice: TrackingService) {}

  @Post('location/:id')
  @UseGuards(new AuthGuard())
  @UsePipes(new ValidationPipe())
  @Roles('soldier')
  async trackLocation(
    @User('id') userId,
    @Param('id') id,
    @Body() trackdata: TrackingDTO,
  ) {
    return this.trackingservice.trackLocation(userId, id, trackdata);
  }
}
