import { Injectable, HttpStatus, HttpException } from '@nestjs/common';
import { Repository } from 'typeorm';
import { Game_PersonEntity } from '../game/game.entity';
import { InjectRepository } from '@nestjs/typeorm';
import { TrackingEntity } from './tracking.entity';
import { TrackingDTO } from './tracking.dto';

@Injectable()
export class TrackingService {
  constructor(
    @InjectRepository(TrackingEntity)
    private trackingrepository: Repository<TrackingEntity>,
    @InjectRepository(Game_PersonEntity)
    private gamepersonrepository: Repository<Game_PersonEntity>,
  ) {}

  async trackLocation(personId, gameId, trackdata: TrackingDTO) {
    // find player
    let gameperson = await this.gamepersonrepository.findOne({
      game: gameId,
      person: personId,
    });
    if (!gameperson) {
      throw new HttpException(
        'You have not joined this game',
        HttpStatus.BAD_REQUEST,
      );
    }
    let trackedperson = await this.trackingrepository.findOne({
      gamepersonId: gameperson,
    });

    // if player has pushed tracking data, update entry
    if (trackedperson) {
      //add coordinates
      trackedperson.data['geometry']['coordinates'].push(
        await this.mapFunction(trackdata.data['geometry']['coordinates']),
      );
      //add timestamp
      trackedperson.data['geometry']['properties']['time'].push(
        new Date(Date.now()),
      );

      return await this.trackingrepository.save(trackedperson);
    } else {
      // first entry will be empty
      // initialize coordinates
      trackdata.data['geometry']['coordinates'] = [];
      // initialize timestamp
      trackdata.data['geometry']['properties']['time'] = [];
      trackedperson = await this.trackingrepository.create(trackdata);
      trackedperson.gamepersonId = gameperson;
      return await this.trackingrepository.save(trackedperson);
    }
  }

  private async mapFunction(data): Promise<Number> {
    return await data.map(type => {
      return type;
    });
  }
}
